fastHorseshoe-package:
Fast Bayesian horseshoe regression implemented by the elliptical slice sampler.
Description
The elliptical slice sampler for Bayesian linear regression with shrinakge priors such as horseshoe, double-exponential prior. The main function can also implement user-specified prior functions.
Details
For an overview of the package including list of functions and demos, please run
help(package="fastHorseshoe")
References
Hahn, P. Richard, Jingyu He, and Hedibert Lopes. Elliptical slice sampling for Bayesian shrinkage regression with applications to causal inference (2016).